# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.  # noqa: E501

    OpenAPI spec version: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Report(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'created_at': 'datetime',
        'href': 'str',
        'status': 'str',
        'result': 'str',
        'sub_result': 'str',
        'breakdown': 'dict(str, object)',
        'properties': 'dict(str, object)',
        'name': 'str',
        'variant': 'str',
        'options': 'list[ReportOption]',
        'documents': 'list[ReportDocument]'
    }

    attribute_map = {
        'id': 'id',
        'created_at': 'created_at',
        'href': 'href',
        'status': 'status',
        'result': 'result',
        'sub_result': 'sub_result',
        'breakdown': 'breakdown',
        'properties': 'properties',
        'name': 'name',
        'variant': 'variant',
        'options': 'options',
        'documents': 'documents'
    }

    def __init__(self, id=None, created_at=None, href=None, status=None, result=None, sub_result=None, breakdown=None, properties=None, name=None, variant=None, options=None, documents=None):  # noqa: E501
        """Report - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._created_at = None
        self._href = None
        self._status = None
        self._result = None
        self._sub_result = None
        self._breakdown = None
        self._properties = None
        self._name = None
        self._variant = None
        self._options = None
        self._documents = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if created_at is not None:
            self.created_at = created_at
        if href is not None:
            self.href = href
        if status is not None:
            self.status = status
        if result is not None:
            self.result = result
        if sub_result is not None:
            self.sub_result = sub_result
        if breakdown is not None:
            self.breakdown = breakdown
        if properties is not None:
            self.properties = properties
        self.name = name
        if variant is not None:
            self.variant = variant
        if options is not None:
            self.options = options
        if documents is not None:
            self.documents = documents

    @property
    def id(self):
        """Gets the id of this Report.  # noqa: E501

        The unique identifier for the report. Read-only.  # noqa: E501

        :return: The id of this Report.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Report.

        The unique identifier for the report. Read-only.  # noqa: E501

        :param id: The id of this Report.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this Report.  # noqa: E501

        The date and time at which the report was first initiated. Read-only.  # noqa: E501

        :return: The created_at of this Report.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Report.

        The date and time at which the report was first initiated. Read-only.  # noqa: E501

        :param created_at: The created_at of this Report.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def href(self):
        """Gets the href of this Report.  # noqa: E501

        The API endpoint to retrieve the report. Read-only.  # noqa: E501

        :return: The href of this Report.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this Report.

        The API endpoint to retrieve the report. Read-only.  # noqa: E501

        :param href: The href of this Report.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def status(self):
        """Gets the status of this Report.  # noqa: E501

        The current state of the report in the checking process. Read-only.  # noqa: E501

        :return: The status of this Report.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Report.

        The current state of the report in the checking process. Read-only.  # noqa: E501

        :param status: The status of this Report.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def result(self):
        """Gets the result of this Report.  # noqa: E501

        The result of the report. Read-only.  # noqa: E501

        :return: The result of this Report.  # noqa: E501
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this Report.

        The result of the report. Read-only.  # noqa: E501

        :param result: The result of this Report.  # noqa: E501
        :type: str
        """

        self._result = result

    @property
    def sub_result(self):
        """Gets the sub_result of this Report.  # noqa: E501

        The sub_result of the report. It gives a more detailed result for document reports only, and will be null otherwise. Read-only.  # noqa: E501

        :return: The sub_result of this Report.  # noqa: E501
        :rtype: str
        """
        return self._sub_result

    @sub_result.setter
    def sub_result(self, sub_result):
        """Sets the sub_result of this Report.

        The sub_result of the report. It gives a more detailed result for document reports only, and will be null otherwise. Read-only.  # noqa: E501

        :param sub_result: The sub_result of this Report.  # noqa: E501
        :type: str
        """

        self._sub_result = sub_result

    @property
    def breakdown(self):
        """Gets the breakdown of this Report.  # noqa: E501

        The details of the report. This is specific to each type of report. Read-only.  # noqa: E501

        :return: The breakdown of this Report.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._breakdown

    @breakdown.setter
    def breakdown(self, breakdown):
        """Sets the breakdown of this Report.

        The details of the report. This is specific to each type of report. Read-only.  # noqa: E501

        :param breakdown: The breakdown of this Report.  # noqa: E501
        :type: dict(str, object)
        """

        self._breakdown = breakdown

    @property
    def properties(self):
        """Gets the properties of this Report.  # noqa: E501

        The properties associated with the report, if any. Read-only.  # noqa: E501

        :return: The properties of this Report.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this Report.

        The properties associated with the report, if any. Read-only.  # noqa: E501

        :param properties: The properties of this Report.  # noqa: E501
        :type: dict(str, object)
        """

        self._properties = properties

    @property
    def name(self):
        """Gets the name of this Report.  # noqa: E501

        The name of the report type.  # noqa: E501

        :return: The name of this Report.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Report.

        The name of the report type.  # noqa: E501

        :param name: The name of this Report.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def variant(self):
        """Gets the variant of this Report.  # noqa: E501

        The name of the report type variant, if required.  # noqa: E501

        :return: The variant of this Report.  # noqa: E501
        :rtype: str
        """
        return self._variant

    @variant.setter
    def variant(self, variant):
        """Sets the variant of this Report.

        The name of the report type variant, if required.  # noqa: E501

        :param variant: The variant of this Report.  # noqa: E501
        :type: str
        """

        self._variant = variant

    @property
    def options(self):
        """Gets the options of this Report.  # noqa: E501

        List of Report Option objects.  # noqa: E501

        :return: The options of this Report.  # noqa: E501
        :rtype: list[ReportOption]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this Report.

        List of Report Option objects.  # noqa: E501

        :param options: The options of this Report.  # noqa: E501
        :type: list[ReportOption]
        """

        self._options = options

    @property
    def documents(self):
        """Gets the documents of this Report.  # noqa: E501

        Array of objects with document ids that were used in the Onfido engine. [ONLY USED IN A DOCUMENT CHECK]  # noqa: E501

        :return: The documents of this Report.  # noqa: E501
        :rtype: list[ReportDocument]
        """
        return self._documents

    @documents.setter
    def documents(self, documents):
        """Sets the documents of this Report.

        Array of objects with document ids that were used in the Onfido engine. [ONLY USED IN A DOCUMENT CHECK]  # noqa: E501

        :param documents: The documents of this Report.  # noqa: E501
        :type: list[ReportDocument]
        """

        self._documents = documents

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Report):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.  # noqa: E501

    OpenAPI spec version: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import onfido
from onfido.models.report import Report  # noqa: E501
from onfido.rest import ApiException


class TestReport(unittest.TestCase):
    """Report unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReport(self):
        """Test Report"""
        # FIXME: construct object with mandatory attributes with example values
        # model = onfido.models.report.Report()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.  # noqa: E501

    OpenAPI spec version: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Check(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'created_at': 'datetime',
        'href': 'str',
        'status': 'str',
        'result': 'str',
        'download_uri': 'str',
        'form_uri': 'str',
        'redirect_uri': 'str',
        'results_uri': 'str',
        'type': 'str',
        'report_type_groups': 'list[str]',
        'tags': 'list[str]',
        'suppress_form_emails': 'bool',
        'charge_applicant_for_check': 'bool',
        'brand_id': 'str',
        'asynchronous': 'bool',
        'reports': 'list[Report]'
    }

    attribute_map = {
        'id': 'id',
        'created_at': 'created_at',
        'href': 'href',
        'status': 'status',
        'result': 'result',
        'download_uri': 'download_uri',
        'form_uri': 'form_uri',
        'redirect_uri': 'redirect_uri',
        'results_uri': 'results_uri',
        'type': 'type',
        'report_type_groups': 'report_type_groups',
        'tags': 'tags',
        'suppress_form_emails': 'suppress_form_emails',
        'charge_applicant_for_check': 'charge_applicant_for_check',
        'brand_id': 'brand_id',
        'asynchronous': 'asynchronous',
        'reports': 'reports'
    }

    def __init__(self, id=None, created_at=None, href=None, status=None, result=None, download_uri=None, form_uri=None, redirect_uri=None, results_uri=None, type=None, report_type_groups=None, tags=None, suppress_form_emails=None, charge_applicant_for_check=None, brand_id=None, asynchronous=None, reports=None):  # noqa: E501
        """Check - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._created_at = None
        self._href = None
        self._status = None
        self._result = None
        self._download_uri = None
        self._form_uri = None
        self._redirect_uri = None
        self._results_uri = None
        self._type = None
        self._report_type_groups = None
        self._tags = None
        self._suppress_form_emails = None
        self._charge_applicant_for_check = None
        self._brand_id = None
        self._asynchronous = None
        self._reports = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if created_at is not None:
            self.created_at = created_at
        if href is not None:
            self.href = href
        if status is not None:
            self.status = status
        if result is not None:
            self.result = result
        if download_uri is not None:
            self.download_uri = download_uri
        if form_uri is not None:
            self.form_uri = form_uri
        if redirect_uri is not None:
            self.redirect_uri = redirect_uri
        if results_uri is not None:
            self.results_uri = results_uri
        self.type = type
        if report_type_groups is not None:
            self.report_type_groups = report_type_groups
        if tags is not None:
            self.tags = tags
        if suppress_form_emails is not None:
            self.suppress_form_emails = suppress_form_emails
        if charge_applicant_for_check is not None:
            self.charge_applicant_for_check = charge_applicant_for_check
        if brand_id is not None:
            self.brand_id = brand_id
        if asynchronous is not None:
            self.asynchronous = asynchronous
        if reports is not None:
            self.reports = reports

    @property
    def id(self):
        """Gets the id of this Check.  # noqa: E501

        The unique identifier for the check. Read-only.  # noqa: E501

        :return: The id of this Check.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Check.

        The unique identifier for the check. Read-only.  # noqa: E501

        :param id: The id of this Check.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this Check.  # noqa: E501

        The date and time when this check was created. Read-only.  # noqa: E501

        :return: The created_at of this Check.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Check.

        The date and time when this check was created. Read-only.  # noqa: E501

        :param created_at: The created_at of this Check.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def href(self):
        """Gets the href of this Check.  # noqa: E501

        The uri of this resource. Read-only.  # noqa: E501

        :return: The href of this Check.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this Check.

        The uri of this resource. Read-only.  # noqa: E501

        :param href: The href of this Check.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def status(self):
        """Gets the status of this Check.  # noqa: E501

        The current state of the check in the checking process. Read-only.  # noqa: E501

        :return: The status of this Check.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Check.

        The current state of the check in the checking process. Read-only.  # noqa: E501

        :param status: The status of this Check.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def result(self):
        """Gets the result of this Check.  # noqa: E501

        The overall result of the check, based on the results of the constituent reports. Read-only.  # noqa: E501

        :return: The result of this Check.  # noqa: E501
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this Check.

        The overall result of the check, based on the results of the constituent reports. Read-only.  # noqa: E501

        :param result: The result of this Check.  # noqa: E501
        :type: str
        """

        self._result = result

    @property
    def download_uri(self):
        """Gets the download_uri of this Check.  # noqa: E501

        A link to a PDF output of the check results. Append `.pdf` to get the pdf file. Read-only.  # noqa: E501

        :return: The download_uri of this Check.  # noqa: E501
        :rtype: str
        """
        return self._download_uri

    @download_uri.setter
    def download_uri(self, download_uri):
        """Sets the download_uri of this Check.

        A link to a PDF output of the check results. Append `.pdf` to get the pdf file. Read-only.  # noqa: E501

        :param download_uri: The download_uri of this Check.  # noqa: E501
        :type: str
        """

        self._download_uri = download_uri

    @property
    def form_uri(self):
        """Gets the form_uri of this Check.  # noqa: E501

        A link to the applicant form, if the check is of type `standard`. Read-only.  # noqa: E501

        :return: The form_uri of this Check.  # noqa: E501
        :rtype: str
        """
        return self._form_uri

    @form_uri.setter
    def form_uri(self, form_uri):
        """Sets the form_uri of this Check.

        A link to the applicant form, if the check is of type `standard`. Read-only.  # noqa: E501

        :param form_uri: The form_uri of this Check.  # noqa: E501
        :type: str
        """

        self._form_uri = form_uri

    @property
    def redirect_uri(self):
        """Gets the redirect_uri of this Check.  # noqa: E501

        For `standard` checks, redirect to this URI when the applicant has submitted their data. Read-only.  # noqa: E501

        :return: The redirect_uri of this Check.  # noqa: E501
        :rtype: str
        """
        return self._redirect_uri

    @redirect_uri.setter
    def redirect_uri(self, redirect_uri):
        """Sets the redirect_uri of this Check.

        For `standard` checks, redirect to this URI when the applicant has submitted their data. Read-only.  # noqa: E501

        :param redirect_uri: The redirect_uri of this Check.  # noqa: E501
        :type: str
        """

        self._redirect_uri = redirect_uri

    @property
    def results_uri(self):
        """Gets the results_uri of this Check.  # noqa: E501

        A link to the corresponding results page on the Onfido dashboard.  # noqa: E501

        :return: The results_uri of this Check.  # noqa: E501
        :rtype: str
        """
        return self._results_uri

    @results_uri.setter
    def results_uri(self, results_uri):
        """Sets the results_uri of this Check.

        A link to the corresponding results page on the Onfido dashboard.  # noqa: E501

        :param results_uri: The results_uri of this Check.  # noqa: E501
        :type: str
        """

        self._results_uri = results_uri

    @property
    def type(self):
        """Gets the type of this Check.  # noqa: E501

        The type of the check, `standard` or `express`.  # noqa: E501

        :return: The type of this Check.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Check.

        The type of the check, `standard` or `express`.  # noqa: E501

        :param type: The type of this Check.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def report_type_groups(self):
        """Gets the report_type_groups of this Check.  # noqa: E501

        Array containing ids of the Report type groups being requested for. Write-only.  # noqa: E501

        :return: The report_type_groups of this Check.  # noqa: E501
        :rtype: list[str]
        """
        return self._report_type_groups

    @report_type_groups.setter
    def report_type_groups(self, report_type_groups):
        """Sets the report_type_groups of this Check.

        Array containing ids of the Report type groups being requested for. Write-only.  # noqa: E501

        :param report_type_groups: The report_type_groups of this Check.  # noqa: E501
        :type: list[str]
        """

        self._report_type_groups = report_type_groups

    @property
    def tags(self):
        """Gets the tags of this Check.  # noqa: E501

        Array of tags being assigned to this check.  # noqa: E501

        :return: The tags of this Check.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Check.

        Array of tags being assigned to this check.  # noqa: E501

        :param tags: The tags of this Check.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def suppress_form_emails(self):
        """Gets the suppress_form_emails of this Check.  # noqa: E501

        For standard checks, applicant form will not be automatically sent if this is set to true. You can manually send the form at any time after the check has been created, using the link found in the form_uri attribute of the check object. Write-only. Defaults to false.   # noqa: E501

        :return: The suppress_form_emails of this Check.  # noqa: E501
        :rtype: bool
        """
        return self._suppress_form_emails

    @suppress_form_emails.setter
    def suppress_form_emails(self, suppress_form_emails):
        """Sets the suppress_form_emails of this Check.

        For standard checks, applicant form will not be automatically sent if this is set to true. You can manually send the form at any time after the check has been created, using the link found in the form_uri attribute of the check object. Write-only. Defaults to false.   # noqa: E501

        :param suppress_form_emails: The suppress_form_emails of this Check.  # noqa: E501
        :type: bool
        """

        self._suppress_form_emails = suppress_form_emails

    @property
    def charge_applicant_for_check(self):
        """Gets the charge_applicant_for_check of this Check.  # noqa: E501

        For standard checks, applicants will be presented with a mandatory payment screen before they can submit the applicant form, if this is set to true. In this case, your account will not be charged. Write-only. Defaults to false.   # noqa: E501

        :return: The charge_applicant_for_check of this Check.  # noqa: E501
        :rtype: bool
        """
        return self._charge_applicant_for_check

    @charge_applicant_for_check.setter
    def charge_applicant_for_check(self, charge_applicant_for_check):
        """Sets the charge_applicant_for_check of this Check.

        For standard checks, applicants will be presented with a mandatory payment screen before they can submit the applicant form, if this is set to true. In this case, your account will not be charged. Write-only. Defaults to false.   # noqa: E501

        :param charge_applicant_for_check: The charge_applicant_for_check of this Check.  # noqa: E501
        :type: bool
        """

        self._charge_applicant_for_check = charge_applicant_for_check

    @property
    def brand_id(self):
        """Gets the brand_id of this Check.  # noqa: E501

        ID of the brand under which the check should be conducted. Write-only.  # noqa: E501

        :return: The brand_id of this Check.  # noqa: E501
        :rtype: str
        """
        return self._brand_id

    @brand_id.setter
    def brand_id(self, brand_id):
        """Sets the brand_id of this Check.

        ID of the brand under which the check should be conducted. Write-only.  # noqa: E501

        :param brand_id: The brand_id of this Check.  # noqa: E501
        :type: str
        """

        self._brand_id = brand_id

    @property
    def asynchronous(self):
        """Gets the asynchronous of this Check.  # noqa: E501

        If this is set to true, we will queue checks for processing and return a response immediately. You can configure webhooks to notify you when the report is complete. Write-only. Defaults to false.   # noqa: E501

        :return: The asynchronous of this Check.  # noqa: E501
        :rtype: bool
        """
        return self._asynchronous

    @asynchronous.setter
    def asynchronous(self, asynchronous):
        """Sets the asynchronous of this Check.

        If this is set to true, we will queue checks for processing and return a response immediately. You can configure webhooks to notify you when the report is complete. Write-only. Defaults to false.   # noqa: E501

        :param asynchronous: The asynchronous of this Check.  # noqa: E501
        :type: bool
        """

        self._asynchronous = asynchronous

    @property
    def reports(self):
        """Gets the reports of this Check.  # noqa: E501

        An array of reports.  # noqa: E501

        :return: The reports of this Check.  # noqa: E501
        :rtype: list[Report]
        """
        return self._reports

    @reports.setter
    def reports(self, reports):
        """Sets the reports of this Check.

        An array of reports.  # noqa: E501

        :param reports: The reports of this Check.  # noqa: E501
        :type: list[Report]
        """

        self._reports = reports

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Check):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.  # noqa: E501

    OpenAPI spec version: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Webhook(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'token': 'str',
        'href': 'str',
        'url': 'str',
        'enabled': 'bool',
        'environments': 'list[str]',
        'events': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'token': 'token',
        'href': 'href',
        'url': 'url',
        'enabled': 'enabled',
        'environments': 'environments',
        'events': 'events'
    }

    def __init__(self, id=None, token=None, href=None, url=None, enabled=None, environments=None, events=None):  # noqa: E501
        """Webhook - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._token = None
        self._href = None
        self._url = None
        self._enabled = None
        self._environments = None
        self._events = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if token is not None:
            self.token = token
        if href is not None:
            self.href = href
        self.url = url
        if enabled is not None:
            self.enabled = enabled
        if environments is not None:
            self.environments = environments
        if events is not None:
            self.events = events

    @property
    def id(self):
        """Gets the id of this Webhook.  # noqa: E501

        The unique identifier of the webhook. Read-only.  # noqa: E501

        :return: The id of this Webhook.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Webhook.

        The unique identifier of the webhook. Read-only.  # noqa: E501

        :param id: The id of this Webhook.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def token(self):
        """Gets the token of this Webhook.  # noqa: E501

        Webhook secret token used to sign the webhook's payload. Read-only.  # noqa: E501

        :return: The token of this Webhook.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this Webhook.

        Webhook secret token used to sign the webhook's payload. Read-only.  # noqa: E501

        :param token: The token of this Webhook.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def href(self):
        """Gets the href of this Webhook.  # noqa: E501

        The API endpoint to retrieve the webhook. Read-only.  # noqa: E501

        :return: The href of this Webhook.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this Webhook.

        The API endpoint to retrieve the webhook. Read-only.  # noqa: E501

        :param href: The href of this Webhook.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def url(self):
        """Gets the url of this Webhook.  # noqa: E501

        The url that will listen to notifications (must be https).  # noqa: E501

        :return: The url of this Webhook.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Webhook.

        The url that will listen to notifications (must be https).  # noqa: E501

        :param url: The url of this Webhook.  # noqa: E501
        :type: str
        """
        if url is None:
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def enabled(self):
        """Gets the enabled of this Webhook.  # noqa: E501

        Determine if the webhook is active.  # noqa: E501

        :return: The enabled of this Webhook.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this Webhook.

        Determine if the webhook is active.  # noqa: E501

        :param enabled: The enabled of this Webhook.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def environments(self):
        """Gets the environments of this Webhook.  # noqa: E501

        The environments from which the webhook will receive events. Allowed values are “sandbox” and “live”. If the environments parameter is omitted the webhook will receive events from both environments.   # noqa: E501

        :return: The environments of this Webhook.  # noqa: E501
        :rtype: list[str]
        """
        return self._environments

    @environments.setter
    def environments(self, environments):
        """Sets the environments of this Webhook.

        The environments from which the webhook will receive events. Allowed values are “sandbox” and “live”. If the environments parameter is omitted the webhook will receive events from both environments.   # noqa: E501

        :param environments: The environments of this Webhook.  # noqa: E501
        :type: list[str]
        """

        self._environments = environments

    @property
    def events(self):
        """Gets the events of this Webhook.  # noqa: E501

        The events that will be published to the webhook. The supported events are: `report.completed`, `report.withdrawn`, `check.completed`, `check.started`, `check.form_opened`, `check.form_completed`. If the events parameter is omitted all the events will be subscribed.   # noqa: E501

        :return: The events of this Webhook.  # noqa: E501
        :rtype: list[str]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this Webhook.

        The events that will be published to the webhook. The supported events are: `report.completed`, `report.withdrawn`, `check.completed`, `check.started`, `check.form_opened`, `check.form_completed`. If the events parameter is omitted all the events will be subscribed.   # noqa: E501

        :param events: The events of this Webhook.  # noqa: E501
        :type: list[str]
        """

        self._events = events

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Webhook):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.  # noqa: E501

    OpenAPI spec version: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class LivePhoto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'created_at': 'datetime',
        'href': 'str',
        'download_href': 'str',
        'file_name': 'str',
        'file_size': 'int',
        'file_type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_at': 'created_at',
        'href': 'href',
        'download_href': 'download_href',
        'file_name': 'file_name',
        'file_size': 'file_size',
        'file_type': 'file_type'
    }

    def __init__(self, id=None, created_at=None, href=None, download_href=None, file_name=None, file_size=None, file_type=None):  # noqa: E501
        """LivePhoto - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._created_at = None
        self._href = None
        self._download_href = None
        self._file_name = None
        self._file_size = None
        self._file_type = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if created_at is not None:
            self.created_at = created_at
        if href is not None:
            self.href = href
        if download_href is not None:
            self.download_href = download_href
        if file_name is not None:
            self.file_name = file_name
        if file_size is not None:
            self.file_size = file_size
        if file_type is not None:
            self.file_type = file_type

    @property
    def id(self):
        """Gets the id of this LivePhoto.  # noqa: E501

        The unique identifier for the photo.  # noqa: E501

        :return: The id of this LivePhoto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LivePhoto.

        The unique identifier for the photo.  # noqa: E501

        :param id: The id of this LivePhoto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this LivePhoto.  # noqa: E501

        The date and time at which the photo was uploaded.  # noqa: E501

        :return: The created_at of this LivePhoto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this LivePhoto.

        The date and time at which the photo was uploaded.  # noqa: E501

        :param created_at: The created_at of this LivePhoto.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def href(self):
        """Gets the href of this LivePhoto.  # noqa: E501

        The uri of this resource.  # noqa: E501

        :return: The href of this LivePhoto.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this LivePhoto.

        The uri of this resource.  # noqa: E501

        :param href: The href of this LivePhoto.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def download_href(self):
        """Gets the download_href of this LivePhoto.  # noqa: E501

        The uri that can be used to download the photo.  # noqa: E501

        :return: The download_href of this LivePhoto.  # noqa: E501
        :rtype: str
        """
        return self._download_href

    @download_href.setter
    def download_href(self, download_href):
        """Sets the download_href of this LivePhoto.

        The uri that can be used to download the photo.  # noqa: E501

        :param download_href: The download_href of this LivePhoto.  # noqa: E501
        :type: str
        """

        self._download_href = download_href

    @property
    def file_name(self):
        """Gets the file_name of this LivePhoto.  # noqa: E501

        The name of the uploaded file.  # noqa: E501

        :return: The file_name of this LivePhoto.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this LivePhoto.

        The name of the uploaded file.  # noqa: E501

        :param file_name: The file_name of this LivePhoto.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def file_size(self):
        """Gets the file_size of this LivePhoto.  # noqa: E501

        The size of the file in bytes.  # noqa: E501

        :return: The file_size of this LivePhoto.  # noqa: E501
        :rtype: int
        """
        return self._file_size

    @file_size.setter
    def file_size(self, file_size):
        """Sets the file_size of this LivePhoto.

        The size of the file in bytes.  # noqa: E501

        :param file_size: The file_size of this LivePhoto.  # noqa: E501
        :type: int
        """

        self._file_size = file_size

    @property
    def file_type(self):
        """Gets the file_type of this LivePhoto.  # noqa: E501

        The file type of the uploaded file.  # noqa: E501

        :return: The file_type of this LivePhoto.  # noqa: E501
        :rtype: str
        """
        return self._file_type

    @file_type.setter
    def file_type(self, file_type):
        """Sets the file_type of this LivePhoto.

        The file type of the uploaded file.  # noqa: E501

        :param file_type: The file_type of this LivePhoto.  # noqa: E501
        :type: str
        """

        self._file_type = file_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LivePhoto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Onfido API

    The Onfido API is used to submit check requests.  # noqa: E501

    OpenAPI spec version: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "3.0.0"

# import apis into sdk package
from onfido.api.default_api import DefaultApi

# import ApiClient
from onfido.api_client import ApiClient
from onfido.configuration import Configuration
# import models into sdk package
from onfido.models.address import Address
from onfido.models.applicant import Applicant
from onfido.models.applicants_list import ApplicantsList
from onfido.models.check import Check
from onfido.models.check_common import CheckCommon
from onfido.models.check_with_report_ids import CheckWithReportIds
from onfido.models.checks_list import ChecksList
from onfido.models.document import Document
from onfido.models.documents_list import DocumentsList
from onfido.models.error import Error
from onfido.models.generic_address import GenericAddress
from onfido.models.generic_addresses_list import GenericAddressesList
from onfido.models.id_number import IdNumber
from onfido.models.live_photo import LivePhoto
from onfido.models.live_photos_list import LivePhotosList
from onfido.models.live_video import LiveVideo
from onfido.models.live_videos_list import LiveVideosList
from onfido.models.report import Report
from onfido.models.report_document import ReportDocument
from onfido.models.report_option import ReportOption
from onfido.models.report_type import ReportType
from onfido.models.report_type_group import ReportTypeGroup
from onfido.models.report_type_groups_list import ReportTypeGroupsList
from onfido.models.reports_list import ReportsList
from onfido.models.webhook import Webhook
from onfido.models.webhooks_list import WebhooksList
